'''
Hepler for defining feature toggles.
'''
import os

from .utils import as_bool


def toggles(**options):
    '''
    Produces a dict of {name: env(name, default)}
    '''
    return {
        name: as_bool(os.environ.get('TOGGLE_%s' % name, default))
        for name, default in options.items()
    }




from distutils.core import setup

setup(
    name='django-classy-settings',
    version='1.1.3',
    description='Simple class-based settings for Django',
    author='Curtis Maloney',
    author_email='curtis@tinbrain.net',
    packages=[
        'cbs',
        'cbs.base',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Django',
        'Intended Audience :: Developers',
    ],
    install_requires=[
        'Django>=1.6',
    ],
)
